;---- File    	   : GP30Y_REG_A1.2.h
;---- Erstellt 	   : 05.02.2015
;---- Bearbeiter   : HG,SK
;---- Firma        : acam-messelectronic gmbh
;---- Projekt      : GP30Y
;----
;---- Description  : Declarations of register addresses and bitnumbers
; Changes in Version GP30Y_REG_A1.2.h: alternative constants added for compatibility with manual / some bit positions added



;---- Configuration Register ----------------------------------------------

CONST CR_WD_DIS	    		0xC0			;---- Watchdog Disable											
CONST CR_PI_E2P	    		0xC1			;---- Pulse / EEPROM Interface
CONST CR_GP_CTRL			0xC2			;---- General purpose control
CONST CR_UART		    	0xC3			;---- UART Interface
CONST CR_IEH		    	0xC4			;---- Interrupt & Error Handling											
CONST CR_CPM		    	0xC5			;---- Clock & Power Management
CONST CR_MRG_TS				0xC6			;---- Measure rate generater and Task Sequencer										
CONST CR_TM	 	    		0xC7			;---- Temperature Measurement
CONST CR_USM_PRC	    	0xC8			;---- Ultra Sonic Measurement
CONST CR_USM_FRC	    	0xC9			;---- Ultra Sonic Measurement: Fire Receive Control
CONST CR_USM_TOF	    	0xCA			;---- Ultra Sonic Measurement: Time of Flight
CONST CR_USM_AM	    		0xCB			;---- Ultra Sonic Measurement: Amplitude Measurement
CONST CR_TRIM1				0xCC			;---- Trim parameters 1; USM Tuning Parameter
CONST CR_TRIM2				0xCD			;---- Trim parameters 2; TDC Tuning Parameter
CONST CR_TRIM3				0xCE			;---- Trim parameters 3; Analog Functions Tuning Parameter
											

;---- System Handling Register ---------------------------------------------

CONST SHR_TOF_RATE    		0xD0			;---- System Handling: TOF_RATE
CONST SHR_GPO		    	0xD3			;---- System Handling: General Purpose Out
CONST SHR_PI_NPULSE   		0xD4			;---- System Handling: Pulse Interface, Number of Pulses
CONST SHR_PI_TPA   			0xD5			;---- System Handling: Pulse Interface, Distance of Pulses
CONST SHR_PI_IU_TIME 		0xD6			;---- System Handling: Pulse Interface, Auto Update Time
CONST SHR_PI_IU_NO   		0xD7			;---- System Handling: Pulse Interface, Number of Auto Updates
CONST SHR_TOF_START_HIT_DLY		0xD8		;---- System Handling: Start Hit Delay
CONST SHR_ZCD_LVL	    	0xD9			;---- System Handling: ZCD Stored Value
CONST SHR_ZCD_FHL_U 		0xDA			;---- Zero Cross Detection, First Hit Level Up
CONST SHR_ZCD_FHL_D 		0xDB			;---- Zero Cross Detection, First Hit Level Down
CONST SHR_CPU_REQ	    	0xDC			;---- System Handling: CPU Requests
CONST SHR_EXC		    	0xDD			;---- System Handling: Execute Register
CONST SHR_RC		    	0xDE			;---- System Handling: Remote Control
CONST SHR_FW_TRANS_EN		0xDF			;---- System Handling: FW Transaction Enable  							

;---- Status & Result Register ---------------------------------------------

CONST SRR_IRQ_FLAG    		0xE0			;---- Status & Result Register: IRQ Flags
CONST SRR_ERR_FLG	    	0xE1			;---- Status & Result Register: Error Flags
CONST SRR_FEP_STF	    	0xE2			;---- Status & Result Register: FEP Status Flag
CONST SRR_GPI		    	0xE3			;---- Status & Result Register: General Purpose In
CONST SRR_HCC_VAL     		0xE4			;---- Status & Result Register: HCC Value
CONST SRR_VCC_VAL	    	0xE5			;---- Status & Result Register: VCC Value
CONST SRR_TSV_HOUR	    	0xE6			;---- Status & Result Register: Time Stamp Value, Hours					
CONST SRR_TSV_MIN_SEC    	0xE7			;---- Status & Result Register: Time Stamp Value, Minutes & Seconds		
CONST SRR_TOF_CT	    	0xE8			;---- Status & Result Register: TOF Cycle Time							
CONST SRR_TS_TIME	    	0xE9			;---- Status & Result Register: Task Sequencer Time						
CONST SRR_MSC_STF			0xEA			;---- Status & Result Register: Miscellaneous Status Flag
CONST SRR_E2P_RD			0xEB			;---- Status & Result Register: EEPROM Read Data
CONST SRR_FWU_RNG			0xEC			;---- Status & Result Register: FW User Range							
CONST SRR_FWU_REV			0xED			;---- Status & Result Register: FW User Revision						
CONST SRR_FWA_REV			0xEE			;---- Status & Result Register: FW Acam Revision						
CONST SRR_LSC_CV			0xEF			;---- Status & Result Register: Low Speed Clock Count value
										

;================== Special Register Actions =====================================

CONST SR_MCT_DIS			0x00000001		;---- Measure Cycle Timer Disable		8'h8A
CONST SR_MCT_EN				0x00000002		;---- Measure Cycle Timer Enable		8'h8B
CONST SR_PP_DIS				0x00000004		;---- Post Processing Disable
CONST SR_PP_EN				0x00000008		;---- Post Processing Enable
CONST SR_RP_DIS				0x00000010		;---- Remote Processing Disable
CONST SR_RP_RLS				0x00000020		;---- Remote Processing Release
CONST SR_BG_SPM				0x00000040		;---- BG self pulsed
CONST SR_BG_TPM				0x00000080		;---- BG task pulsed
CONST SR_CM_PM_NOK			0x00000100		;---- CM & PM not OK
CONST SR_CM_PM_OK			0x00000200		;---- CM & PM OK
CONST SR_NVM_TRIM_DIS		0x00000400		;---- NVM Trimming Disable
CONST SR_NVM_TRIM_EN		0x00000800		;---- NVM Trimming Enable
CONST SR_HSC_4MHZ			0x00000004		;---- High Speed Clock / div 1 (4 MHz) 
CONST SR_HSC_8MHZ			0x00000008		;---- High Speed Clock / div 1 (4 MHz) 
CONST SR_PI_DIS				0x00004000		;---- Disable Pulse Interface
CONST SR_PI_EN				0x00008000		;---- Enable Pulse Interface

CONST SR_PM_STORE			0x00010000		;---- CM_PM Store
CONST SR_BM_STORE			0x00020000		;---- BM Store
CONST SR_CM_RECALL			0x00040000		;---- CM Recall
CONST SR_PM_RECALL			0x00080000		;---- PM Recall
CONST SR_BM_RECALL			0x00100000		;---- BM Recall

CONST SR_EH_CLR				0x00000001		;---- EH Clear
CONST SR_FES_CLR			0x00000002		;---- FES Clear
CONST SR_CFG_DONE			0x00000002
CONST SR_TSC_CLR			0x00000004		;---- TSC Clear
CONST SR_TSV_UPD			0x00000008		;---- TSV Update
CONST SR_TOF_RATE_CLR		0x00000010		;---- TSV Update
CONST SR_BG_REFRESH			0x00000020		;---- TSV Update
CONST SR_UART_CRC_ON		0x00000020
CONST SR_IF_CLR				0x00000040		;---- EH Clear
CONST SR_WD_CLR				0x00000080		;---- WD Clear
CONST SR_PI_UPD				0x00000100		;---- PI Update

CONST SR_WD_DIS				0x48DBA399		;---- WD Disable
CONST SR_STORE_EN			0xA0F5B8CA		;---- Store Enable
CONST SR_TEST_EN			0x6107C9DB		;---- Test Enable
CONST SR_FW_RLS				0xABCD7654		;---- NV Ok


;================== Bit Numbers of CPU Request Register SHR_CPU_REQ =====================================
CONST BNR_BLD_EXC			0 				;---- CPU request boot loader execute
CONST BNR_CHKSUM			1 				;---- Request Checksum Generation
CONST BNR_PP				2 				;---- Post Processing
CONST BNR_EH				3 				;---- Error Handling; do not use
CONST BNR_GPH				4 				;---- General Purpose Handling
CONST BNR_FWI				5 				;---- Request Firmware Initialization

;================== Bit Numbers of SHR_GPO Register =====================================
CONST BNR_GPO0_OUT			 0  			;---- General Purpose 0 Out
CONST BNR_GPO1_OUT			 1  			;---- General Purpose 1 Out
CONST BNR_GPO2_OUT			 2 				;---- General Purpose 2 Out
CONST BNR_GPO3_OUT			 3  			;---- General Purpose 3 Out
CONST BNR_GPO4_OUT			 4  			;---- General Purpose 4 Out
CONST BNR_GPO5_OUT			 5  			;---- General Purpose 5 Out
CONST BNR_GPO6_OUT			 6  			;---- General Purpose 6 Out
                                                  
CONST BNR_PI_OUT_FRC0		 8 				;---- Forces Low on Pulse Output
CONST BNR_PI_OUT_FRC1		 9 				;---- Forces High on Pulse Output
CONST BNR_PI_DIR_FRC0		10 				;---- Forces Low on Pulse Direction
CONST BNR_PI_DIR_FRC1		11 				;---- Forces High on Pulse Direction
CONST BNR_FWD1_CSE			12 				;---- FWD1 Checksum Error
CONST BNR_FWD2_CSE			13 				;---- FWD2 Checksum Error
CONST BNR_FWU_CSE			14 				;---- FWU Checksum Error
CONST BNR_FWA_CSE			15 				;---- FWA Checksum Error

;================== Bit Numbers of Execute Register SHR_EXC ==================================
CONST BNR_IF_CLR  			0 				;---- Interrupt Flag Clear
CONST BNR_EF_CLR			1 				;---- Error Flags Clear
CONST BNR_FES_CLR			2				;---- Frontend Status Clear
CONST BNR_TSC_CLR			3 				;---- Timestamp Counter Clear					
CONST BNR_TSV_UPD			4 				;---- Timestamp Value Update					
CONST BNR_PI_UPD  			5 				;---- Pulse Interface Update
CONST BNR_BG_REFRESH  		6 				;---- Bandgap Refresh
CONST BNR_E2P_CLR			7				;---- EEPROM Clear						
CONST BNR_TOF_RATE_CLR 		8 				;---- TOF Rate Clear
CONST BNR_ZCC_RNG_CLR		9				;---- Zero Cross Calibration: Range Clear		
CONST BNR_FW_IRQ_S			10				;---- Firmware Interrupt Request, synchronized  
CONST BNR_FW_IRQ			11				;---- Firmware Interrupt Request				
CONST BNR_COM_REQ_CLR		12				;---- Communication Request Clear				
CONST BNR_GPR_REQ_CLR		13				;---- General Purpose Request Clear				
CONST BNR_GPH_TRIG			14				;---- General Purpose Trigger (via Task Seq.)	
CONST BNR_BUH_TRIG			15				;---- Backup Handling Trigger (via Task Seq.) ; Do not use !	


;================== some Bit Numbers of various Config Registers =====================================
CONST BNR_PI_EN				8 				;---- Pulse Interface Enable, register CR_PI_E2P          
CONST BNR_HS_CLK_DIV		8				;---- High Speed Clock divider=HS_CLK_SEL, 4MHz (0) or 8MHz (1), register CR_CPM 
CONST BNR_HS_CLK_SEL		8				;---- HS_CLK_SEL, 4MHz (0) or 8MHz (1), register CR_CPM
CONST BNR_CRC_MODE			13				;---- UART CRC operating with default (0) or with configured settings (1), register CR_UART
CONST BNR_BLD_CS			31				;---- Checksum Execution after Bootloader enabled (1), register CR_IEH

; Configuration register bits for Temperature Measurement in CR_TM 
CONST BNR_TM_PORT_NO		16				;---- Number of ports (for external measurement)
CONST BNR_TM_EXT_MODE		15				;---- 2 or 4 wire (Temperature extern mode)
CONST BNR_TM_MODE_1			14				;---- Temperature Measurement Mode: If 1 then toggling
CONST BNR_TM_MODE_0			13				;---- Temperature Measurement Mode

;================== Bit Numbers of FEP Status Flag Register SRR_FEP_STF =====================================
CONST BNR_HCC_UPD			0 				;---- High Speed Clock Calibration Update
CONST BNR_TM_UPD			1 				;---- Temperature Update
CONST BNR_TM_MODE			2				;---- Temperature Measurement Mode
CONST BNR_TM_ST				3				;---- Temperature Measurement Subtask
CONST BNR_US_U_UPD			4 				;---- US Up Update
CONST BNR_US_D_UPD			5 				;---- US Down Update
CONST BNR_TOF_UPD			6 				;---- TOF Update
CONST BNR_TOF_EDGE			7				;---- TOF Measurement edge
CONST BNR_AM_UPD			8 				;---- AM Update                  
CONST BNR_AMC_UPD			9 				;---- AMC Update
                 

;================== Bit Numbers of Interrupt Flags (SRR_IRQ_FLAG) Register ==========================
CONST BNR_ERR_FLAG			7				;---- 1 when at least one error flag is set

CONST BNR_SRR_FW_IRQ		5				;---- Firmware Interrupt Request
CONST BNR_SRR_FW_IRQ_S		4				;---- Firmware Interrupt Request, synchronized with task sequencer
CONST BNR_CHKSUM_FNS		3				;---- Checksum Subroutine Finished
CONST BNR_BLD_FNS			2				;---- Bootloader Finished

;================== Bit Numbers of Error Flags (SRR_ERR_FLAG) Register ==========================
CONST BNR_CS_FWA_ERR		15				;---- FWA checksum error
CONST BNR_CS_FWU_ERR		14				;---- FWU checksum error
CONST BNR_CS_FWD2_ERR		13				;---- FWD2 checksum error
CONST BNR_CS_FWD1_ERR		12				;---- FWD1 checksum error

CONST BNR_E2P_ACK_ERR		10				;---- EEPROM Acknowledge Error
CONST BNR_TSQ_TMO			9				;---- Task Sequencer timeout
CONST BNR_TM_SQC_TMO		8				;---- Temperature sequence timeout
CONST BNR_USM_SQC_TMO		7				;---- Ultrasonic sequence timeout
CONST BNR_LBD_ERR			6				;---- Low Battery Detect Error
CONST BNR_ZCC_ERR			5				;---- Zero Cross Calibration Error
CONST BNR_TM_SC_ERR			4				;---- Temperature Measurement Short Circuit Error
CONST BNR_TM_OC_ERR			3				;---- Temperature Measurement Open Circuit Error
CONST BNR_AM_TMO			2				;---- Amplitude Measurement Timeout
CONST BNR_TOF_TMO			1				;---- TOF Timeout
CONST BNR_TDC_TMO			0				;---- TDC Timeout

;================== Bit Numbers of General Purpose In (SRR_GPI) Register ==========================
CONST BNR_LS_CLK_S			11				;---- Low speed clock, synchronized to CPU clock
CONST BNR_NVM_RDY			10				;---- NVRAM ready
CONST BNR_UART_SEL			9				;---- UART Select
CONST BNR_LP_MODE			8				;---- Low Power Mode

CONST BNR_GPI6_IN			6				;---- GPI 6 in
CONST BNR_GPI5_IN			5				;---- GPI 5 in
CONST BNR_GPI4_IN			4				;---- GPI 4 in
CONST BNR_GPI3_IN			3				;---- GPI 3 in
CONST BNR_GPI2_IN			2				;---- GPI 2 in
CONST BNR_GPI1_IN			1				;---- GPI 1 in
CONST BNR_GPI0_IN			0				;---- GPI 0 in

;================== Bit Numbers of Miscellaneous Status Flag Register SRR_MSC_STF =============================
CONST BNR_WD_DIS			15				;---- Watchdog Disabled

CONST BNR_E2P_ACK			13				;---- EEPROM Acknowledge
CONST BNR_GPR_REQ			5				;---- General purpose Request by remote interface
CONST BNR_COM_REQ			4				;---- Communication Request by remote interface






;-----------------------------------------------------------------------------------------------------
